Calendrical.Formatter.InvalidOptionError exception (Calendrical v0.3.0)

Exception raised when an unknown option, or an option with an invalid value, is supplied to a calendar formatter.

Fields

  • :option — the option name that was supplied.
  • :value — the value that was supplied for the option.