Calendrical.InvalidCalendarModuleError exception (Calendrical v0.3.0)

Exception raised when a module is referenced as a calendar but does not implement the Calendar (and Calendrical) behaviour.

Fields

  • :module — the module that was expected to be a calendar.