Calendrical.InvalidDateOrderError exception (Calendrical v0.3.0)

Exception raised when two dates or times are not ordered from earlier to later as required by the function being called.

Fields

  • :from — the earlier value (as supplied).
  • :to — the later value (as supplied).