Calendrical.IslamicYearOutOfRangeError exception
(Calendrical v0.3.0)
Exception raised when an operation on the Umm al-Qura Islamic calendar references a Hijri year that lies outside the embedded reference data.
Fields
:year— the Hijri year that was requested, ornilwhen the input was not a year (e.g. an out-of-range ISO day number).:min_year— the first Hijri year covered by the embedded data.:max_year— the last Hijri year covered by the embedded data.