Calendrical.MissingFieldsError exception
(Calendrical v0.3.0)
Exception raised when a date or datetime does not have all the fields required by the function being called.
Fields
:function— the name of the function that required the fields, as a string.:fields— a keyword list whose keys are the required field names and whose values are the values that were found (nilfor missing fields).